@@ -23,14 +23,6 @@ class RequestHelper:
         'Content-Type': 'application/x-www-form-urlencoded',
     }
 
-    desktopHeader = {
-        'User-Agent': (
-            'Mozilla/5.0 (Linux; Android 7.1.1; Moto G Play Build/NPIS26.48-43-2; wv) AppleWebKit/537.36'
-            + ' (KHTML, like Gecko) Version/4.0 Chrome/71.0.3578.99 Mobile Safari/537.36'
-        ),
-        'Content-Type': 'application/x-www-form-urlencoded',
-    }
-
     def __init__(
         self,
         moodle_domain: str,
