@@ -20,6 +20,7 @@ class ResultsHandler:
         self.moodle_path = moodle_path
         self.course_assignments = {}
         self.course_databases = {}
+        self.course_forums = {}
 
     def setVersion(self, version: int):
         self.version = version
@@ -106,6 +107,13 @@ class ResultsHandler:
 
                 files += self._handle_files(section_name, module_name, module_modname, module_id, database_files)
 
+            elif module_modname == 'forum':
+                # find forums with same module_id
+                forums = self.course_forums.get(module_id, {})
+                forums_files = forums.get('files', [])
+
+                files += self._handle_files(section_name, module_name, module_modname, module_id, forums_files)
+
         return files
 
     @staticmethod
@@ -120,7 +128,13 @@ class ResultsHandler:
         return description
 
     def _find_all_urls_in_description(
-        self, section_name: str, module_name: str, module_modname: str, module_id: str, description: str
+        self,
+        section_name: str,
+        module_name: str,
+        module_modname: str,
+        module_id: str,
+        content_filepath: str,
+        description: str,
     ) -> [File]:
         """Parses a description to find all urls in it. Then it creates for every url a file entry.
 
@@ -139,24 +153,26 @@ class ResultsHandler:
         urls += list(set(re.findall(r'src=[\'"]?([^\'" >]+)', description)))
 
         result = []
+        original_module_modname = module_modname
+
         for url in urls:
             if url == '':
                 continue
 
-            module_modname = 'url-description'
+            module_modname = 'url-description-' + original_module_modname
 
             url_parts = urlparse.urlparse(url)
             if url_parts.hostname == self.moodle_domain and url_parts.path.find('/webservice/') >= 0:
-                module_modname = 'index_mod-description'
+                module_modname = 'index_mod-description-' + original_module_modname
 
             elif url_parts.hostname == self.moodle_domain:
-                module_modname = 'cookie_mod-description'
+                module_modname = 'cookie_mod-description-' + original_module_modname
 
             new_file = File(
                 module_id=module_id,
                 section_name=section_name,
                 module_name=module_name,
-                content_filepath='/',
+                content_filepath=content_filepath,
                 content_filename=url,
                 content_fileurl=url,
                 content_filesize=0,
@@ -253,7 +269,7 @@ class ResultsHandler:
             if content_type == 'description':
                 new_file.text_content = content_description
                 files += self._find_all_urls_in_description(
-                    section_name, module_name, module_modname, module_id, content_description
+                    section_name, module_name, module_modname, module_id, content_filepath, content_description
                 )
 
             files.append(new_file)
@@ -302,22 +318,24 @@ class ResultsHandler:
 
         description.text_content = module_description
         files += self._find_all_urls_in_description(
-            section_name, module_name, module_modname, module_id, module_description
+            section_name, module_name, module_modname, module_id, content_filepath, module_description
         )
 
         files.append(description)
 
         return files
 
-    def set_fetch_addons(self, course_assignments: {int: {int: {}}}, course_databases: {int: {int: {}}}):
+    def set_fetch_addons(self, course_assignments: {}, course_databases: {}, course_forums: {}):
         """
         Sets the optional data that will be added to the result list
          during the process.
         @params course_assignments: The dictionary of assignments per course
         @params course_databases: The dictionary of databases per course
+        @params course_forums: The dictionary of forums per course
         """
         self.course_assignments = course_assignments
         self.course_databases = course_databases
+        self.course_forums = course_forums
 
     def fetch_files(self, course_id: str) -> [File]:
         """
