@@ -172,6 +172,18 @@ class StateRecorder:
 
         if file1.content_type == file2.content_type and file1.module_modname == file2.module_modname:
             return True
+
+        elif (
+            file1.content_type == 'description-url'
+            and file1.content_type == file2.content_type
+            and (
+                file1.module_modname.startswith(file2.module_modname)
+                or file2.module_modname.startswith(file1.module_modname)
+            )
+        ):
+            # stop redownloading old description urls. Sorry the  module_modname structure has changed
+            return True
+
         return False
 
     def __files_have_same_path(self, file1: File, file2: File) -> bool:
@@ -224,6 +236,13 @@ class StateRecorder:
             return True
         return False
 
+    def __ignore_deleted(self, file: File):
+        # Returns true if the deleted file should be ignored.
+        if file.module_modname.endswith('forum'):
+            return True
+
+        return False
+
     def get_stored_files(self) -> [Course]:
         # get all stored files (that are not yet deleted)
         conn = sqlite3.connect(self.db_file)
@@ -325,12 +344,13 @@ class StateRecorder:
                         # file does still exist
                         break
 
-                if matching_file is None:
+                if matching_file is None and not self.__ignore_deleted(stored_file):
                     # No matching file was found --> file was deleted
                     stored_file.deleted = True
                     stored_file.notified = False
                     changed_course.files.append(stored_file)
-                else:
+
+                elif matching_file is not None:
                     matching_file.moved = True
                     matching_file.old_file = stored_file
                     changed_course.files.append(matching_file)
@@ -422,6 +442,29 @@ class StateRecorder:
 
         return changed_courses
 
+    def get_last_timestamps_per_forum(self) -> {}:
+        """Returns a dict of timestamps per forum cmid"""
+
+        conn = sqlite3.connect(self.db_file)
+        conn.row_factory = sqlite3.Row
+        cursor = conn.cursor()
+        result_dict = {}
+
+        cursor.execute(
+            """SELECT module_id, max(content_timemodified) as content_timemodified
+            FROM files WHERE module_modname = 'forum' AND content_type = 'description'
+            GROUP BY module_id;"""
+        )
+
+        curse_rows = cursor.fetchall()
+
+        for course_row in curse_rows:
+            result_dict[course_row['module_id']] = course_row['content_timemodified']
+
+        conn.close()
+
+        return result_dict
+
     def changes_to_notify(self) -> [Course]:
         changed_courses = []
 
